@@ -5,8 +5,7 @@
 #' @param string a character vector
 #' @export
 #' @family other_helpers
-.escape_regex <- function (string)
-{
+.escape_regex <- function(string) {
   gsub(
     "([.|()\\^{}+$*?]|\\[|\\])", "\\\\\\1",
     string
@@ -26,6 +25,8 @@
 #' @export
 #' @family other_helpers
 .clean_backticks <- function(x, variable_names = x) {
+  saved_names <- names(x)
+
   variable_names <- variable_names %>%
     stats::na.omit() %>%
     unique() %>%
@@ -49,6 +50,7 @@
       v
     )
   }
+  names(x) <- saved_names
   x
 }
 
