@@ -2,7 +2,7 @@
 #'
 #' Add a `contrasts` column corresponding to contrasts used for a
 #' categorical variable and a `contrasts_type` column equal to
-#' "treatment", "sum", "poly", "helmert" or "other".
+#' "treatment", "sum", "poly", "helmert", "other" or "no.contrast".
 #'
 #' @details
 #' If the `variable` column is not yet available in `x`,
@@ -10,6 +10,7 @@
 #'
 #' @param x a tidy tibble
 #' @param model the corresponding model, if not attached to `x`
+#' @param quiet logical argument whether broom.helpers should not return a message when `tidy_disambiguate_terms()` was already applied
 #' @export
 #' @family tidy_helpers
 #' @examples
@@ -25,7 +26,7 @@
 #'   ) %>%
 #'   tidy_and_attach() %>%
 #'   tidy_add_contrasts()
-tidy_add_contrasts <- function(x, model = tidy_get_model(x)) {
+tidy_add_contrasts <- function(x, model = tidy_get_model(x), quiet = FALSE) {
   if (is.null(model)) {
     stop("'model' is not provided. You need to pass it or to use 'tidy_and_attach()'.")
   }
@@ -37,6 +38,8 @@ tidy_add_contrasts <- function(x, model = tidy_get_model(x)) {
   }
 
   if (!"variable" %in% names(x)) {
+    if (!quiet)
+
     x <- x %>% tidy_identify_variables()
   }
 
