@@ -211,46 +211,13 @@ tibble::tribble(
 ) %>%
     gt::gt() %>%
   gt::fmt_markdown(columns = everything()) %>%
-  gt::tab_options(
-    column_labels.font.weight = "bold"
-  ) %>%
+  gt::tab_options(column_labels.font.weight = "bold") %>%
   gt::opt_row_striping() %>%
   gt::tab_style("vertical-align:top; font-size: 12px;", gt::cells_body())
 
 ## ---- echo=FALSE--------------------------------------------------------------
-tibble::tribble(
-  ~Model, ~Notes,
-  '`stats::lm()`', '',
-  '`stats::glm()`', '',
-  '`stats::aov()`', 'Reference rows are not relevant for such models.',
-  '`ordinal::clm()`', 'Limited support for models with nominal predictors.',
-  '`ordinal::clmm()`', 'Limited support for models with nominal predictors.',
-  '`survival::coxph()`', '',
-  '`survival::survreg()`', '',
-  '`survival::clogit()`', '',
-  '`lme4::lmer()`', '`broom.mixed` package required',
-  '`lme4::glmer()`', '`broom.mixed` package required',
-  '`lme4::glmer.nb()`', '`broom.mixed` package required',
-  '`brms::brm()`', '`broom.mixed` package required',
-  '`geepack::geeglm()`', '',
-  '`gam::gam()`', '',
-  '`glmmTMB::glmmTMB()`', '`broom.mixed` package required',
-  '`mgcv::gam()`', 'Use default tidier `broom::tidy()` for smooth terms only, or `gtsummary::tidy_gam()` to include parametric terms',
-  '`nnet::multinom()`', '',
-  '`survey::svyglm()`', '',
-  '`survey::svycoxph∟()`', '',
-  '`survey::svyolr()`', '',
-  '`MASS::polr()`', '',
-  '`MASS::glm.nb()`', '',
-  '`mice::mira`', 'Limited support. If `mod` is a `mira` object, use `tidy_plus_plus(mod, tidy_fun = function(x, ...) mice::pool(x) %>% mice::tidy(...))`',
-  '`lavaan::lavaan()`', 'Limited support for categorical variables',
-  '`stats::nls()`', 'Limited support',
-  '`lfe::felm()`', '',
-  '`rstanarm::stan_glm()`', '`broom.mixed` package required',
-  '`VGAM::vglm()`', 'Limited support. It is recommanded to use `tidy_parameters()` as `tidy_fun`.',
-  '`cmprsk::crr()`', 'Limited support. It is recommanded to use `tidycmprsk::crr()` instead.',
-  '`tidycmprsk::crr()`', ''
-) %>%
+supported_models %>%
+  dplyr::rename_with(stringr::str_to_title) %>%
   dplyr::arrange(Model) %>%
   gt::gt() %>%
   gt::fmt_markdown(columns = everything()) %>%
